<?php
/**
 * Counter Section options
 *
 * @package Theme Palace
 * @subpackage Travel Route Pro
 * @since Travel Route Pro 1.0.0
 */

// Add Counter section
$wp_customize->add_section( 'travel_base_pro_counter_section', array(
	'title'             => esc_html__( 'Counter','travel-base-pro' ),
	'description'       => esc_html__( 'Counter Section options.', 'travel-base-pro' ),
	'panel'             => 'travel_base_pro_front_page_panel',
) );

// Counter content enable control and setting
$wp_customize->add_setting( 'travel_base_pro_theme_options[counter_section_enable]', array(
	'default'			=> 	$options['counter_section_enable'],
	'sanitize_callback' => 'travel_base_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Base_Pro_Switch_Control( $wp_customize, 'travel_base_pro_theme_options[counter_section_enable]', array(
	'label'             => esc_html__( 'Counter Section Enable', 'travel-base-pro' ),
	'section'           => 'travel_base_pro_counter_section',
	'on_off_label' 		=> travel_base_pro_switch_options(),
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_base_pro_theme_options[counter_subtitle]', array(
		'selector'            => '#counter-section .section-header span.section-subtitle',
		'settings'            => 'travel_base_pro_theme_options[counter_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_base_pro_counter_subtitle_partial',
    ) );
}

// counter image setting and control.
$wp_customize->add_setting( 'travel_base_pro_theme_options[counter_image]', array(
	'sanitize_callback' => 'travel_base_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'travel_base_pro_theme_options[counter_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'travel-base-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'travel-base-pro' ), 1920, 500 ),
		'section'     		=> 'travel_base_pro_counter_section',
		'active_callback'	=> 'travel_base_pro_is_counter_section_enable',
) ) );

for ( $i = 1; $i <= 4; $i++ ) :

	// counter icon setting and control
	$wp_customize->add_setting( 'travel_base_pro_theme_options[counter_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Travel_Base_Pro_Icon_Picker( $wp_customize, 'travel_base_pro_theme_options[counter_icon_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Icon %d', 'travel-base-pro' ), $i ),
		'section'        	=> 'travel_base_pro_counter_section',
		'active_callback' 	=> 'travel_base_pro_is_counter_section_enable',
	) ) );

	// counter title setting and control
	$wp_customize->add_setting( 'travel_base_pro_theme_options[counter_value_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'travel_base_pro_theme_options[counter_value_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Value %d', 'travel-base-pro' ), $i ),
		'section'        	=> 'travel_base_pro_counter_section',
		'active_callback' 	=> 'travel_base_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter position setting and control
	$wp_customize->add_setting( 'travel_base_pro_theme_options[counter_label_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'travel_base_pro_theme_options[counter_label_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Label %d', 'travel-base-pro' ), $i ),
		'section'        	=> 'travel_base_pro_counter_section',
		'active_callback' 	=> 'travel_base_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter hr setting and control
	$wp_customize->add_setting( 'travel_base_pro_theme_options[counter_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Travel_Base_Pro_Customize_Horizontal_Line( $wp_customize, 'travel_base_pro_theme_options[counter_hr_'. $i .']',
		array(
			'section'         => 'travel_base_pro_counter_section',
			'active_callback' => 'travel_base_pro_is_counter_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;

