<?php
/**
 * Featured Section options
 *
 * @featured Theme Palace
 * @subfeatured Travel Base Pro
 * @since Travel Base Pro 1.0.0
 */

// Add Featured section
$wp_customize->add_section( 'travel_base_pro_featured_section', array(
	'title'             => esc_html__( 'Featured','travel-base-pro' ),
	'description'       => esc_html__( 'Featured Section options.', 'travel-base-pro' ),
	'panel'             => 'travel_base_pro_front_page_panel',
) );

// Featured content enable control and setting
$wp_customize->add_setting( 'travel_base_pro_theme_options[featured_section_enable]', array(
	'default'			=> 	$options['featured_section_enable'],
	'sanitize_callback' => 'travel_base_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Base_Pro_Switch_Control( $wp_customize, 'travel_base_pro_theme_options[featured_section_enable]', array(
	'label'             => esc_html__( 'Featured Section Enable', 'travel-base-pro' ),
	'section'           => 'travel_base_pro_featured_section',
	'on_off_label' 		=> travel_base_pro_switch_options(),
) ) );

// Featured content type control and setting
$wp_customize->add_setting( 'travel_base_pro_theme_options[featured_content_type]', array(
	'default'          	=> $options['featured_content_type'],
	'sanitize_callback' => 'travel_base_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_base_pro_theme_options[featured_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-base-pro' ),
	'section'           => 'travel_base_pro_featured_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_base_pro_is_featured_section_enable',
	'choices'			=> travel_base_pro_traveler_choice_content_type(),
) );

for ( $i=1; $i <= 2; $i++ ) { 
	// featured pages drop down chooser control and setting
	$wp_customize->add_setting( 'travel_base_pro_theme_options[featured_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travel_base_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Base_Pro_Dropdown_Chooser( $wp_customize, 'travel_base_pro_theme_options[featured_content_page_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Page %d', 'travel-base-pro' ), $i ),
		'section'           => 'travel_base_pro_featured_section',
		'choices'			=> travel_base_pro_page_choices(),
		'active_callback'	=> 'travel_base_pro_is_featured_section_content_page_enable',
	) ) );

	// featured posts drop down chooser control and setting
	$wp_customize->add_setting( 'travel_base_pro_theme_options[featured_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travel_base_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Base_Pro_Dropdown_Chooser( $wp_customize, 'travel_base_pro_theme_options[featured_content_post_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select posts %d', 'travel-base-pro' ), $i ),
		'section'           => 'travel_base_pro_featured_section',
		'choices'			=> travel_base_pro_post_choices(),
		'active_callback'	=> 'travel_base_pro_is_featured_section_content_post_enable',
	) ) );

	// featured trips drop down chooser control and setting
	$wp_customize->add_setting( 'travel_base_pro_theme_options[featured_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'travel_base_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Base_Pro_Dropdown_Chooser( $wp_customize, 'travel_base_pro_theme_options[featured_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'travel-base-pro' ), $i ),
		'section'           => 'travel_base_pro_featured_section',
		'choices'			=> travel_base_pro_trip_choices(),
		'active_callback'	=> 'travel_base_pro_is_featured_section_content_trip_enable',
	) ) );

	// popular destination read more setting and control
	$wp_customize->add_setting( 'travel_base_pro_theme_options[featured_read_more_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'travel_base_pro_theme_options[featured_read_more_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Button Text %d', 'travel-base-pro' ), $i ),
		'section'        	=> 'travel_base_pro_featured_section',
		'active_callback' 	=> 'travel_base_pro_is_featured_section_enable',
		'type'				=> 'text',
	) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_base_pro_theme_options[featured_content_category]', array(
	'sanitize_callback' => 'travel_base_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Travel_Base_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_base_pro_theme_options[featured_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travel-base-pro' ),
	'description'      	=> esc_html__( 'Note: Featured selected no of posts will be shown from selected category', 'travel-base-pro' ),
	'section'           => 'travel_base_pro_featured_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_base_pro_is_featured_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_base_pro_theme_options[featured_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Travel_Base_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_base_pro_theme_options[featured_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'travel-base-pro' ),
	'section'           => 'travel_base_pro_featured_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_base_pro_is_featured_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_base_pro_theme_options[featured_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Travel_Base_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_base_pro_theme_options[featured_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'travel-base-pro' ),
	'section'           => 'travel_base_pro_featured_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_base_pro_is_featured_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_base_pro_theme_options[featured_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Travel_Base_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_base_pro_theme_options[featured_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'travel-base-pro' ),
	'section'           => 'travel_base_pro_featured_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_base_pro_is_featured_section_content_destination_enable'
) ) );

